# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TeamMatchup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'team1': 'str',
        'team2': 'str',
        'start_year': 'int',
        'end_year': 'int',
        'team1_wins': 'int',
        'team2_wins': 'int',
        'ties': 'int',
        'games': 'list[TeamMatchupGames]'
    }

    attribute_map = {
        'team1': 'team1',
        'team2': 'team2',
        'start_year': 'startYear',
        'end_year': 'endYear',
        'team1_wins': 'team1Wins',
        'team2_wins': 'team2Wins',
        'ties': 'ties',
        'games': 'games'
    }

    def __init__(self, team1=None, team2=None, start_year=None, end_year=None, team1_wins=None, team2_wins=None, ties=None, games=None):  # noqa: E501
        """TeamMatchup - a model defined in Swagger"""  # noqa: E501

        self._team1 = None
        self._team2 = None
        self._start_year = None
        self._end_year = None
        self._team1_wins = None
        self._team2_wins = None
        self._ties = None
        self._games = None
        self.discriminator = None

        if team1 is not None:
            self.team1 = team1
        if team2 is not None:
            self.team2 = team2
        if start_year is not None:
            self.start_year = start_year
        if end_year is not None:
            self.end_year = end_year
        if team1_wins is not None:
            self.team1_wins = team1_wins
        if team2_wins is not None:
            self.team2_wins = team2_wins
        if ties is not None:
            self.ties = ties
        if games is not None:
            self.games = games

    @property
    def team1(self):
        """Gets the team1 of this TeamMatchup.  # noqa: E501


        :return: The team1 of this TeamMatchup.  # noqa: E501
        :rtype: str
        """
        return self._team1

    @team1.setter
    def team1(self, team1):
        """Sets the team1 of this TeamMatchup.


        :param team1: The team1 of this TeamMatchup.  # noqa: E501
        :type: str
        """

        self._team1 = team1

    @property
    def team2(self):
        """Gets the team2 of this TeamMatchup.  # noqa: E501


        :return: The team2 of this TeamMatchup.  # noqa: E501
        :rtype: str
        """
        return self._team2

    @team2.setter
    def team2(self, team2):
        """Sets the team2 of this TeamMatchup.


        :param team2: The team2 of this TeamMatchup.  # noqa: E501
        :type: str
        """

        self._team2 = team2

    @property
    def start_year(self):
        """Gets the start_year of this TeamMatchup.  # noqa: E501


        :return: The start_year of this TeamMatchup.  # noqa: E501
        :rtype: int
        """
        return self._start_year

    @start_year.setter
    def start_year(self, start_year):
        """Sets the start_year of this TeamMatchup.


        :param start_year: The start_year of this TeamMatchup.  # noqa: E501
        :type: int
        """

        self._start_year = start_year

    @property
    def end_year(self):
        """Gets the end_year of this TeamMatchup.  # noqa: E501


        :return: The end_year of this TeamMatchup.  # noqa: E501
        :rtype: int
        """
        return self._end_year

    @end_year.setter
    def end_year(self, end_year):
        """Sets the end_year of this TeamMatchup.


        :param end_year: The end_year of this TeamMatchup.  # noqa: E501
        :type: int
        """

        self._end_year = end_year

    @property
    def team1_wins(self):
        """Gets the team1_wins of this TeamMatchup.  # noqa: E501


        :return: The team1_wins of this TeamMatchup.  # noqa: E501
        :rtype: int
        """
        return self._team1_wins

    @team1_wins.setter
    def team1_wins(self, team1_wins):
        """Sets the team1_wins of this TeamMatchup.


        :param team1_wins: The team1_wins of this TeamMatchup.  # noqa: E501
        :type: int
        """

        self._team1_wins = team1_wins

    @property
    def team2_wins(self):
        """Gets the team2_wins of this TeamMatchup.  # noqa: E501


        :return: The team2_wins of this TeamMatchup.  # noqa: E501
        :rtype: int
        """
        return self._team2_wins

    @team2_wins.setter
    def team2_wins(self, team2_wins):
        """Sets the team2_wins of this TeamMatchup.


        :param team2_wins: The team2_wins of this TeamMatchup.  # noqa: E501
        :type: int
        """

        self._team2_wins = team2_wins

    @property
    def ties(self):
        """Gets the ties of this TeamMatchup.  # noqa: E501


        :return: The ties of this TeamMatchup.  # noqa: E501
        :rtype: int
        """
        return self._ties

    @ties.setter
    def ties(self, ties):
        """Sets the ties of this TeamMatchup.


        :param ties: The ties of this TeamMatchup.  # noqa: E501
        :type: int
        """

        self._ties = ties

    @property
    def games(self):
        """Gets the games of this TeamMatchup.  # noqa: E501


        :return: The games of this TeamMatchup.  # noqa: E501
        :rtype: list[TeamMatchupGames]
        """
        return self._games

    @games.setter
    def games(self, games):
        """Sets the games of this TeamMatchup.


        :param games: The games of this TeamMatchup.  # noqa: E501
        :type: list[TeamMatchupGames]
        """

        self._games = games

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamMatchup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamMatchup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TeamGameTeams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'school': 'str',
        'conference': 'str',
        'home_away': 'bool',
        'points': 'int',
        'stats': 'list[TeamGameStats]'
    }

    attribute_map = {
        'school': 'school',
        'conference': 'conference',
        'home_away': 'homeAway',
        'points': 'points',
        'stats': 'stats'
    }

    def __init__(self, school=None, conference=None, home_away=None, points=None, stats=None):  # noqa: E501
        """TeamGameTeams - a model defined in Swagger"""  # noqa: E501

        self._school = None
        self._conference = None
        self._home_away = None
        self._points = None
        self._stats = None
        self.discriminator = None

        if school is not None:
            self.school = school
        if conference is not None:
            self.conference = conference
        if home_away is not None:
            self.home_away = home_away
        if points is not None:
            self.points = points
        if stats is not None:
            self.stats = stats

    @property
    def school(self):
        """Gets the school of this TeamGameTeams.  # noqa: E501


        :return: The school of this TeamGameTeams.  # noqa: E501
        :rtype: str
        """
        return self._school

    @school.setter
    def school(self, school):
        """Sets the school of this TeamGameTeams.


        :param school: The school of this TeamGameTeams.  # noqa: E501
        :type: str
        """

        self._school = school

    @property
    def conference(self):
        """Gets the conference of this TeamGameTeams.  # noqa: E501


        :return: The conference of this TeamGameTeams.  # noqa: E501
        :rtype: str
        """
        return self._conference

    @conference.setter
    def conference(self, conference):
        """Sets the conference of this TeamGameTeams.


        :param conference: The conference of this TeamGameTeams.  # noqa: E501
        :type: str
        """

        self._conference = conference

    @property
    def home_away(self):
        """Gets the home_away of this TeamGameTeams.  # noqa: E501


        :return: The home_away of this TeamGameTeams.  # noqa: E501
        :rtype: bool
        """
        return self._home_away

    @home_away.setter
    def home_away(self, home_away):
        """Sets the home_away of this TeamGameTeams.


        :param home_away: The home_away of this TeamGameTeams.  # noqa: E501
        :type: bool
        """

        self._home_away = home_away

    @property
    def points(self):
        """Gets the points of this TeamGameTeams.  # noqa: E501


        :return: The points of this TeamGameTeams.  # noqa: E501
        :rtype: int
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this TeamGameTeams.


        :param points: The points of this TeamGameTeams.  # noqa: E501
        :type: int
        """

        self._points = points

    @property
    def stats(self):
        """Gets the stats of this TeamGameTeams.  # noqa: E501


        :return: The stats of this TeamGameTeams.  # noqa: E501
        :rtype: list[TeamGameStats]
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this TeamGameTeams.


        :param stats: The stats of this TeamGameTeams.  # noqa: E501
        :type: list[TeamGameStats]
        """

        self._stats = stats

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamGameTeams, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamGameTeams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BoxScorePlayersPpa(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'player': 'str',
        'team': 'str',
        'position': 'str',
        'average': 'BoxScorePlayersAverage',
        'cumulative': 'BoxScorePlayersAverage'
    }

    attribute_map = {
        'player': 'player',
        'team': 'team',
        'position': 'position',
        'average': 'average',
        'cumulative': 'cumulative'
    }

    def __init__(self, player=None, team=None, position=None, average=None, cumulative=None):  # noqa: E501
        """BoxScorePlayersPpa - a model defined in Swagger"""  # noqa: E501

        self._player = None
        self._team = None
        self._position = None
        self._average = None
        self._cumulative = None
        self.discriminator = None

        if player is not None:
            self.player = player
        if team is not None:
            self.team = team
        if position is not None:
            self.position = position
        if average is not None:
            self.average = average
        if cumulative is not None:
            self.cumulative = cumulative

    @property
    def player(self):
        """Gets the player of this BoxScorePlayersPpa.  # noqa: E501


        :return: The player of this BoxScorePlayersPpa.  # noqa: E501
        :rtype: str
        """
        return self._player

    @player.setter
    def player(self, player):
        """Sets the player of this BoxScorePlayersPpa.


        :param player: The player of this BoxScorePlayersPpa.  # noqa: E501
        :type: str
        """

        self._player = player

    @property
    def team(self):
        """Gets the team of this BoxScorePlayersPpa.  # noqa: E501


        :return: The team of this BoxScorePlayersPpa.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this BoxScorePlayersPpa.


        :param team: The team of this BoxScorePlayersPpa.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def position(self):
        """Gets the position of this BoxScorePlayersPpa.  # noqa: E501


        :return: The position of this BoxScorePlayersPpa.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this BoxScorePlayersPpa.


        :param position: The position of this BoxScorePlayersPpa.  # noqa: E501
        :type: str
        """

        self._position = position

    @property
    def average(self):
        """Gets the average of this BoxScorePlayersPpa.  # noqa: E501


        :return: The average of this BoxScorePlayersPpa.  # noqa: E501
        :rtype: BoxScorePlayersAverage
        """
        return self._average

    @average.setter
    def average(self, average):
        """Sets the average of this BoxScorePlayersPpa.


        :param average: The average of this BoxScorePlayersPpa.  # noqa: E501
        :type: BoxScorePlayersAverage
        """

        self._average = average

    @property
    def cumulative(self):
        """Gets the cumulative of this BoxScorePlayersPpa.  # noqa: E501


        :return: The cumulative of this BoxScorePlayersPpa.  # noqa: E501
        :rtype: BoxScorePlayersAverage
        """
        return self._cumulative

    @cumulative.setter
    def cumulative(self, cumulative):
        """Sets the cumulative of this BoxScorePlayersPpa.


        :param cumulative: The cumulative of this BoxScorePlayersPpa.  # noqa: E501
        :type: BoxScorePlayersAverage
        """

        self._cumulative = cumulative

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BoxScorePlayersPpa, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BoxScorePlayersPpa):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cfbd.api_client import ApiClient


class TeamsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_fbs_teams(self, **kwargs):  # noqa: E501
        """FBS team list  # noqa: E501

        Information on major division teams  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_fbs_teams(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :return: list[Team]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_fbs_teams_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_fbs_teams_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_fbs_teams_with_http_info(self, **kwargs):  # noqa: E501
        """FBS team list  # noqa: E501

        Information on major division teams  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_fbs_teams_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :return: list[Team]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_fbs_teams" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 1869:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_fbs_teams`, must be a value greater than or equal to `1869`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teams/fbs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Team]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_roster(self, team, **kwargs):  # noqa: E501
        """Team rosters  # noqa: E501

        Roster data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_roster(team, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team: Team name (required)
        :param int year: Season year
        :return: list[Player]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_roster_with_http_info(team, **kwargs)  # noqa: E501
        else:
            (data) = self.get_roster_with_http_info(team, **kwargs)  # noqa: E501
            return data

    def get_roster_with_http_info(self, team, **kwargs):  # noqa: E501
        """Team rosters  # noqa: E501

        Roster data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_roster_with_http_info(team, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team: Team name (required)
        :param int year: Season year
        :return: list[Player]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team', 'year']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_roster" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team' is set
        if ('team' not in params or
                params['team'] is None):
            raise ValueError("Missing the required parameter `team` when calling `get_roster`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/roster', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Player]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_talent(self, **kwargs):  # noqa: E501
        """Team talent composite rankings  # noqa: E501

        Team talent composite  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_talent(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :return: list[TeamTalent]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_talent_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_talent_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_talent_with_http_info(self, **kwargs):  # noqa: E501
        """Team talent composite rankings  # noqa: E501

        Team talent composite  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_talent_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :return: list[TeamTalent]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_talent" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 2015:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_talent`, must be a value greater than or equal to `2015`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/talent', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamTalent]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_matchup(self, team1, team2, **kwargs):  # noqa: E501
        """Team matchup history  # noqa: E501

        Matchup history  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_matchup(team1, team2, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team1: First team (required)
        :param str team2: Second team (required)
        :param int min_year: Minimum year
        :param int max_year: Maximum year
        :return: list[TeamMatchup]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_matchup_with_http_info(team1, team2, **kwargs)  # noqa: E501
        else:
            (data) = self.get_team_matchup_with_http_info(team1, team2, **kwargs)  # noqa: E501
            return data

    def get_team_matchup_with_http_info(self, team1, team2, **kwargs):  # noqa: E501
        """Team matchup history  # noqa: E501

        Matchup history  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_matchup_with_http_info(team1, team2, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str team1: First team (required)
        :param str team2: Second team (required)
        :param int min_year: Minimum year
        :param int max_year: Maximum year
        :return: list[TeamMatchup]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team1', 'team2', 'min_year', 'max_year']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_matchup" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team1' is set
        if ('team1' not in params or
                params['team1'] is None):
            raise ValueError("Missing the required parameter `team1` when calling `get_team_matchup`")  # noqa: E501
        # verify the required parameter 'team2' is set
        if ('team2' not in params or
                params['team2'] is None):
            raise ValueError("Missing the required parameter `team2` when calling `get_team_matchup`")  # noqa: E501

        if 'max_year' in params and params['max_year'] < 1869:  # noqa: E501
            raise ValueError("Invalid value for parameter `max_year` when calling `get_team_matchup`, must be a value greater than or equal to `1869`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'team1' in params:
            query_params.append(('team1', params['team1']))  # noqa: E501
        if 'team2' in params:
            query_params.append(('team2', params['team2']))  # noqa: E501
        if 'min_year' in params:
            query_params.append(('minYear', params['min_year']))  # noqa: E501
        if 'max_year' in params:
            query_params.append(('maxYear', params['max_year']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teams/matchup', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamMatchup]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_teams(self, **kwargs):  # noqa: E501
        """Team information  # noqa: E501

        Get team information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_teams(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str conference: Conference abbreviation filter
        :return: list[Team]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_teams_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_teams_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_teams_with_http_info(self, **kwargs):  # noqa: E501
        """Team information  # noqa: E501

        Get team information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_teams_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str conference: Conference abbreviation filter
        :return: list[Team]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_teams" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teams', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Team]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.api.players_api import PlayersApi  # noqa: E501
from cfbd.rest import ApiException


class TestPlayersApi(unittest.TestCase):
    """PlayersApi unit test stubs"""

    def setUp(self):
        self.api = cfbd.api.players_api.PlayersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_player_season_stats(self):
        """Test case for get_player_season_stats

        Player stats by season  # noqa: E501
        """
        pass

    def test_get_player_usage(self):
        """Test case for get_player_usage

        Player usage metrics broken down by season  # noqa: E501
        """
        pass

    def test_get_returning_production(self):
        """Test case for get_returning_production

        Team returning production metrics  # noqa: E501
        """
        pass

    def test_player_search(self):
        """Test case for player_search

        Search for player information  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.api.games_api import GamesApi  # noqa: E501
from cfbd.rest import ApiException


class TestGamesApi(unittest.TestCase):
    """GamesApi unit test stubs"""

    def setUp(self):
        self.api = cfbd.api.games_api.GamesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_advanced_box_score(self):
        """Test case for get_advanced_box_score

        Advanced box scores  # noqa: E501
        """
        pass

    def test_get_game_media(self):
        """Test case for get_game_media

        Game media information and schedules  # noqa: E501
        """
        pass

    def test_get_games(self):
        """Test case for get_games

        Games and results  # noqa: E501
        """
        pass

    def test_get_player_game_stats(self):
        """Test case for get_player_game_stats

        Player game stats  # noqa: E501
        """
        pass

    def test_get_team_game_stats(self):
        """Test case for get_team_game_stats

        Team game stats  # noqa: E501
        """
        pass

    def test_get_team_records(self):
        """Test case for get_team_records

        Team records  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AdvancedSeasonStatOffense(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'plays': 'int',
        'drives': 'int',
        'ppa': 'float',
        'total_ppa': 'float',
        'success_rate': 'float',
        'explosiveness': 'float',
        'power_success': 'float',
        'stuff_rate': 'float',
        'line_yards': 'float',
        'line_yards_total': 'float',
        'second_level_yards': 'float',
        'second_level_yards_total': 'int',
        'open_field_yards': 'float',
        'open_field_yards_total': 'int',
        'points_per_opportunity': 'float',
        'field_position': 'AdvancedSeasonStatOffenseFieldPosition',
        'standard_downs': 'AdvancedSeasonStatOffenseStandardDowns',
        'passing_downs': 'AdvancedSeasonStatOffenseStandardDowns',
        'rushing_plays': 'AdvancedSeasonStatOffenseRushingPlays',
        'passing_plays': 'AdvancedSeasonStatOffenseRushingPlays'
    }

    attribute_map = {
        'plays': 'plays',
        'drives': 'drives',
        'ppa': 'ppa',
        'total_ppa': 'totalPPA',
        'success_rate': 'successRate',
        'explosiveness': 'explosiveness',
        'power_success': 'powerSuccess',
        'stuff_rate': 'stuffRate',
        'line_yards': 'lineYards',
        'line_yards_total': 'lineYardsTotal',
        'second_level_yards': 'secondLevelYards',
        'second_level_yards_total': 'secondLevelYardsTotal',
        'open_field_yards': 'openFieldYards',
        'open_field_yards_total': 'openFieldYardsTotal',
        'points_per_opportunity': 'pointsPerOpportunity',
        'field_position': 'fieldPosition',
        'standard_downs': 'standardDowns',
        'passing_downs': 'passingDowns',
        'rushing_plays': 'rushingPlays',
        'passing_plays': 'passingPlays'
    }

    def __init__(self, plays=None, drives=None, ppa=None, total_ppa=None, success_rate=None, explosiveness=None, power_success=None, stuff_rate=None, line_yards=None, line_yards_total=None, second_level_yards=None, second_level_yards_total=None, open_field_yards=None, open_field_yards_total=None, points_per_opportunity=None, field_position=None, standard_downs=None, passing_downs=None, rushing_plays=None, passing_plays=None):  # noqa: E501
        """AdvancedSeasonStatOffense - a model defined in Swagger"""  # noqa: E501

        self._plays = None
        self._drives = None
        self._ppa = None
        self._total_ppa = None
        self._success_rate = None
        self._explosiveness = None
        self._power_success = None
        self._stuff_rate = None
        self._line_yards = None
        self._line_yards_total = None
        self._second_level_yards = None
        self._second_level_yards_total = None
        self._open_field_yards = None
        self._open_field_yards_total = None
        self._points_per_opportunity = None
        self._field_position = None
        self._standard_downs = None
        self._passing_downs = None
        self._rushing_plays = None
        self._passing_plays = None
        self.discriminator = None

        if plays is not None:
            self.plays = plays
        if drives is not None:
            self.drives = drives
        if ppa is not None:
            self.ppa = ppa
        if total_ppa is not None:
            self.total_ppa = total_ppa
        if success_rate is not None:
            self.success_rate = success_rate
        if explosiveness is not None:
            self.explosiveness = explosiveness
        if power_success is not None:
            self.power_success = power_success
        if stuff_rate is not None:
            self.stuff_rate = stuff_rate
        if line_yards is not None:
            self.line_yards = line_yards
        if line_yards_total is not None:
            self.line_yards_total = line_yards_total
        if second_level_yards is not None:
            self.second_level_yards = second_level_yards
        if second_level_yards_total is not None:
            self.second_level_yards_total = second_level_yards_total
        if open_field_yards is not None:
            self.open_field_yards = open_field_yards
        if open_field_yards_total is not None:
            self.open_field_yards_total = open_field_yards_total
        if points_per_opportunity is not None:
            self.points_per_opportunity = points_per_opportunity
        if field_position is not None:
            self.field_position = field_position
        if standard_downs is not None:
            self.standard_downs = standard_downs
        if passing_downs is not None:
            self.passing_downs = passing_downs
        if rushing_plays is not None:
            self.rushing_plays = rushing_plays
        if passing_plays is not None:
            self.passing_plays = passing_plays

    @property
    def plays(self):
        """Gets the plays of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The plays of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: int
        """
        return self._plays

    @plays.setter
    def plays(self, plays):
        """Sets the plays of this AdvancedSeasonStatOffense.


        :param plays: The plays of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: int
        """

        self._plays = plays

    @property
    def drives(self):
        """Gets the drives of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The drives of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: int
        """
        return self._drives

    @drives.setter
    def drives(self, drives):
        """Sets the drives of this AdvancedSeasonStatOffense.


        :param drives: The drives of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: int
        """

        self._drives = drives

    @property
    def ppa(self):
        """Gets the ppa of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The ppa of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._ppa

    @ppa.setter
    def ppa(self, ppa):
        """Sets the ppa of this AdvancedSeasonStatOffense.


        :param ppa: The ppa of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._ppa = ppa

    @property
    def total_ppa(self):
        """Gets the total_ppa of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The total_ppa of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._total_ppa

    @total_ppa.setter
    def total_ppa(self, total_ppa):
        """Sets the total_ppa of this AdvancedSeasonStatOffense.


        :param total_ppa: The total_ppa of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._total_ppa = total_ppa

    @property
    def success_rate(self):
        """Gets the success_rate of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The success_rate of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._success_rate

    @success_rate.setter
    def success_rate(self, success_rate):
        """Sets the success_rate of this AdvancedSeasonStatOffense.


        :param success_rate: The success_rate of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._success_rate = success_rate

    @property
    def explosiveness(self):
        """Gets the explosiveness of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The explosiveness of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._explosiveness

    @explosiveness.setter
    def explosiveness(self, explosiveness):
        """Sets the explosiveness of this AdvancedSeasonStatOffense.


        :param explosiveness: The explosiveness of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._explosiveness = explosiveness

    @property
    def power_success(self):
        """Gets the power_success of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The power_success of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._power_success

    @power_success.setter
    def power_success(self, power_success):
        """Sets the power_success of this AdvancedSeasonStatOffense.


        :param power_success: The power_success of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._power_success = power_success

    @property
    def stuff_rate(self):
        """Gets the stuff_rate of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The stuff_rate of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._stuff_rate

    @stuff_rate.setter
    def stuff_rate(self, stuff_rate):
        """Sets the stuff_rate of this AdvancedSeasonStatOffense.


        :param stuff_rate: The stuff_rate of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._stuff_rate = stuff_rate

    @property
    def line_yards(self):
        """Gets the line_yards of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The line_yards of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._line_yards

    @line_yards.setter
    def line_yards(self, line_yards):
        """Sets the line_yards of this AdvancedSeasonStatOffense.


        :param line_yards: The line_yards of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._line_yards = line_yards

    @property
    def line_yards_total(self):
        """Gets the line_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The line_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._line_yards_total

    @line_yards_total.setter
    def line_yards_total(self, line_yards_total):
        """Sets the line_yards_total of this AdvancedSeasonStatOffense.


        :param line_yards_total: The line_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._line_yards_total = line_yards_total

    @property
    def second_level_yards(self):
        """Gets the second_level_yards of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The second_level_yards of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._second_level_yards

    @second_level_yards.setter
    def second_level_yards(self, second_level_yards):
        """Sets the second_level_yards of this AdvancedSeasonStatOffense.


        :param second_level_yards: The second_level_yards of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._second_level_yards = second_level_yards

    @property
    def second_level_yards_total(self):
        """Gets the second_level_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The second_level_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: int
        """
        return self._second_level_yards_total

    @second_level_yards_total.setter
    def second_level_yards_total(self, second_level_yards_total):
        """Sets the second_level_yards_total of this AdvancedSeasonStatOffense.


        :param second_level_yards_total: The second_level_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: int
        """

        self._second_level_yards_total = second_level_yards_total

    @property
    def open_field_yards(self):
        """Gets the open_field_yards of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The open_field_yards of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._open_field_yards

    @open_field_yards.setter
    def open_field_yards(self, open_field_yards):
        """Sets the open_field_yards of this AdvancedSeasonStatOffense.


        :param open_field_yards: The open_field_yards of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._open_field_yards = open_field_yards

    @property
    def open_field_yards_total(self):
        """Gets the open_field_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The open_field_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: int
        """
        return self._open_field_yards_total

    @open_field_yards_total.setter
    def open_field_yards_total(self, open_field_yards_total):
        """Sets the open_field_yards_total of this AdvancedSeasonStatOffense.


        :param open_field_yards_total: The open_field_yards_total of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: int
        """

        self._open_field_yards_total = open_field_yards_total

    @property
    def points_per_opportunity(self):
        """Gets the points_per_opportunity of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The points_per_opportunity of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: float
        """
        return self._points_per_opportunity

    @points_per_opportunity.setter
    def points_per_opportunity(self, points_per_opportunity):
        """Sets the points_per_opportunity of this AdvancedSeasonStatOffense.


        :param points_per_opportunity: The points_per_opportunity of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: float
        """

        self._points_per_opportunity = points_per_opportunity

    @property
    def field_position(self):
        """Gets the field_position of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The field_position of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: AdvancedSeasonStatOffenseFieldPosition
        """
        return self._field_position

    @field_position.setter
    def field_position(self, field_position):
        """Sets the field_position of this AdvancedSeasonStatOffense.


        :param field_position: The field_position of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: AdvancedSeasonStatOffenseFieldPosition
        """

        self._field_position = field_position

    @property
    def standard_downs(self):
        """Gets the standard_downs of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The standard_downs of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: AdvancedSeasonStatOffenseStandardDowns
        """
        return self._standard_downs

    @standard_downs.setter
    def standard_downs(self, standard_downs):
        """Sets the standard_downs of this AdvancedSeasonStatOffense.


        :param standard_downs: The standard_downs of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: AdvancedSeasonStatOffenseStandardDowns
        """

        self._standard_downs = standard_downs

    @property
    def passing_downs(self):
        """Gets the passing_downs of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The passing_downs of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: AdvancedSeasonStatOffenseStandardDowns
        """
        return self._passing_downs

    @passing_downs.setter
    def passing_downs(self, passing_downs):
        """Sets the passing_downs of this AdvancedSeasonStatOffense.


        :param passing_downs: The passing_downs of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: AdvancedSeasonStatOffenseStandardDowns
        """

        self._passing_downs = passing_downs

    @property
    def rushing_plays(self):
        """Gets the rushing_plays of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The rushing_plays of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: AdvancedSeasonStatOffenseRushingPlays
        """
        return self._rushing_plays

    @rushing_plays.setter
    def rushing_plays(self, rushing_plays):
        """Sets the rushing_plays of this AdvancedSeasonStatOffense.


        :param rushing_plays: The rushing_plays of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: AdvancedSeasonStatOffenseRushingPlays
        """

        self._rushing_plays = rushing_plays

    @property
    def passing_plays(self):
        """Gets the passing_plays of this AdvancedSeasonStatOffense.  # noqa: E501


        :return: The passing_plays of this AdvancedSeasonStatOffense.  # noqa: E501
        :rtype: AdvancedSeasonStatOffenseRushingPlays
        """
        return self._passing_plays

    @passing_plays.setter
    def passing_plays(self, passing_plays):
        """Sets the passing_plays of this AdvancedSeasonStatOffense.


        :param passing_plays: The passing_plays of this AdvancedSeasonStatOffense.  # noqa: E501
        :type: AdvancedSeasonStatOffenseRushingPlays
        """

        self._passing_plays = passing_plays

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdvancedSeasonStatOffense, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdvancedSeasonStatOffense):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cfbd.api_client import ApiClient


class GamesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_advanced_box_score(self, game_id, **kwargs):  # noqa: E501
        """Advanced box scores  # noqa: E501

        Get advanced box score data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advanced_box_score(game_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int game_id: Game id parameters (required)
        :return: list[BoxScore]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_advanced_box_score_with_http_info(game_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_advanced_box_score_with_http_info(game_id, **kwargs)  # noqa: E501
            return data

    def get_advanced_box_score_with_http_info(self, game_id, **kwargs):  # noqa: E501
        """Advanced box scores  # noqa: E501

        Get advanced box score data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_advanced_box_score_with_http_info(game_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int game_id: Game id parameters (required)
        :return: list[BoxScore]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['game_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_advanced_box_score" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'game_id' is set
        if ('game_id' not in params or
                params['game_id'] is None):
            raise ValueError("Missing the required parameter `game_id` when calling `get_advanced_box_score`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'game_id' in params:
            query_params.append(('gameId', params['game_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/game/box/advanced', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[BoxScore]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_game_media(self, year, **kwargs):  # noqa: E501
        """Game media information and schedules  # noqa: E501

        Game media information (TV, radio, etc)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_game_media(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular, postseason, or both)
        :param str team: Team filter
        :param str conference: Conference filter
        :param str media_type: Media type filter (tv, radio, web, ppv, or mobile)
        :return: list[GameMedia]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_game_media_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_game_media_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_game_media_with_http_info(self, year, **kwargs):  # noqa: E501
        """Game media information and schedules  # noqa: E501

        Game media information (TV, radio, etc)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_game_media_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular, postseason, or both)
        :param str team: Team filter
        :param str conference: Conference filter
        :param str media_type: Media type filter (tv, radio, web, ppv, or mobile)
        :return: list[GameMedia]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'season_type', 'team', 'conference', 'media_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_game_media" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if ('year' not in params or
                params['year'] is None):
            raise ValueError("Missing the required parameter `year` when calling `get_game_media`")  # noqa: E501

        if 'year' in params and params['year'] < 2001:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_game_media`, must be a value greater than or equal to `2001`")  # noqa: E501
        if 'week' in params and params['week'] > 16:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_game_media`, must be a value less than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'media_type' in params:
            query_params.append(('mediaType', params['media_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/games/media', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GameMedia]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_games(self, year, **kwargs):  # noqa: E501
        """Games and results  # noqa: E501

        Get game results  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_games(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team
        :param str home: Home team filter
        :param str away: Away team filter
        :param str conference: Conference abbreviation filter
        :param int id: id filter for querying a single game
        :return: list[Game]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_games_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_games_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_games_with_http_info(self, year, **kwargs):  # noqa: E501
        """Games and results  # noqa: E501

        Get game results  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_games_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team
        :param str home: Home team filter
        :param str away: Away team filter
        :param str conference: Conference abbreviation filter
        :param int id: id filter for querying a single game
        :return: list[Game]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'season_type', 'team', 'home', 'away', 'conference', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_games" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if ('year' not in params or
                params['year'] is None):
            raise ValueError("Missing the required parameter `year` when calling `get_games`")  # noqa: E501

        if 'year' in params and params['year'] < 1869:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_games`, must be a value greater than or equal to `1869`")  # noqa: E501
        if 'week' in params and params['week'] > 16:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_games`, must be a value less than or equal to `16`")  # noqa: E501
        if 'week' in params and params['week'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_games`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'home' in params:
            query_params.append(('home', params['home']))  # noqa: E501
        if 'away' in params:
            query_params.append(('away', params['away']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'id' in params:
            query_params.append(('id', params['id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/games', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Game]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_player_game_stats(self, year, **kwargs):  # noqa: E501
        """Player game stats  # noqa: E501

        Player stats broken down by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_player_game_stats(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param str category: Category filter (e.g defensive)
        :param int game_id: Game id filter
        :return: list[PlayerGame]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_player_game_stats_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_player_game_stats_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_player_game_stats_with_http_info(self, year, **kwargs):  # noqa: E501
        """Player game stats  # noqa: E501

        Player stats broken down by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_player_game_stats_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param str category: Category filter (e.g defensive)
        :param int game_id: Game id filter
        :return: list[PlayerGame]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'season_type', 'team', 'conference', 'category', 'game_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_player_game_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if ('year' not in params or
                params['year'] is None):
            raise ValueError("Missing the required parameter `year` when calling `get_player_game_stats`")  # noqa: E501

        if 'week' in params and params['week'] > 16:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_player_game_stats`, must be a value less than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'category' in params:
            query_params.append(('category', params['category']))  # noqa: E501
        if 'game_id' in params:
            query_params.append(('gameId', params['game_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/games/players', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PlayerGame]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_game_stats(self, year, **kwargs):  # noqa: E501
        """Team game stats  # noqa: E501

        Team stats broken down by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_game_stats(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param int game_id: Game id filter
        :return: list[TeamGame]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_game_stats_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_team_game_stats_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_team_game_stats_with_http_info(self, year, **kwargs):  # noqa: E501
        """Team game stats  # noqa: E501

        Team stats broken down by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_game_stats_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year/season filter for games (required)
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param int game_id: Game id filter
        :return: list[TeamGame]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'season_type', 'team', 'conference', 'game_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_game_stats" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if ('year' not in params or
                params['year'] is None):
            raise ValueError("Missing the required parameter `year` when calling `get_team_game_stats`")  # noqa: E501

        if 'year' in params and params['year'] < 2001:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_team_game_stats`, must be a value greater than or equal to `2001`")  # noqa: E501
        if 'week' in params and params['week'] > 16:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_team_game_stats`, must be a value less than or equal to `16`")  # noqa: E501
        if 'week' in params and params['week'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_team_game_stats`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'game_id' in params:
            query_params.append(('gameId', params['game_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/games/teams', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamGame]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_records(self, **kwargs):  # noqa: E501
        """Team records  # noqa: E501

        Get team records by year  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_records(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param str team: Team filter
        :param str conference: Conference filter
        :return: list[TeamRecord]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_records_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_team_records_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_team_records_with_http_info(self, **kwargs):  # noqa: E501
        """Team records  # noqa: E501

        Get team records by year  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_records_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param str team: Team filter
        :param str conference: Conference filter
        :return: list[TeamRecord]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'team', 'conference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_records" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 1869:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_team_records`, must be a value greater than or equal to `1869`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/records', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamRecord]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Team(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'school': 'str',
        'mascot': 'str',
        'abbreviation': 'str',
        'alt_name_1': 'str',
        'alt_name_2': 'str',
        'alt_name_3': 'str',
        'conference': 'str',
        'division': 'str',
        'color': 'str',
        'alt_color': 'str',
        'logos': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'school': 'school',
        'mascot': 'mascot',
        'abbreviation': 'abbreviation',
        'alt_name_1': 'alt_name_1',
        'alt_name_2': 'alt_name_2',
        'alt_name_3': 'alt_name_3',
        'conference': 'conference',
        'division': 'division',
        'color': 'color',
        'alt_color': 'alt_color',
        'logos': 'logos'
    }

    def __init__(self, id=None, school=None, mascot=None, abbreviation=None, alt_name_1=None, alt_name_2=None, alt_name_3=None, conference=None, division=None, color=None, alt_color=None, logos=None):  # noqa: E501
        """Team - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._school = None
        self._mascot = None
        self._abbreviation = None
        self._alt_name_1 = None
        self._alt_name_2 = None
        self._alt_name_3 = None
        self._conference = None
        self._division = None
        self._color = None
        self._alt_color = None
        self._logos = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if school is not None:
            self.school = school
        if mascot is not None:
            self.mascot = mascot
        if abbreviation is not None:
            self.abbreviation = abbreviation
        if alt_name_1 is not None:
            self.alt_name_1 = alt_name_1
        if alt_name_2 is not None:
            self.alt_name_2 = alt_name_2
        if alt_name_3 is not None:
            self.alt_name_3 = alt_name_3
        if conference is not None:
            self.conference = conference
        if division is not None:
            self.division = division
        if color is not None:
            self.color = color
        if alt_color is not None:
            self.alt_color = alt_color
        if logos is not None:
            self.logos = logos

    @property
    def id(self):
        """Gets the id of this Team.  # noqa: E501


        :return: The id of this Team.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Team.


        :param id: The id of this Team.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def school(self):
        """Gets the school of this Team.  # noqa: E501


        :return: The school of this Team.  # noqa: E501
        :rtype: str
        """
        return self._school

    @school.setter
    def school(self, school):
        """Sets the school of this Team.


        :param school: The school of this Team.  # noqa: E501
        :type: str
        """

        self._school = school

    @property
    def mascot(self):
        """Gets the mascot of this Team.  # noqa: E501


        :return: The mascot of this Team.  # noqa: E501
        :rtype: str
        """
        return self._mascot

    @mascot.setter
    def mascot(self, mascot):
        """Sets the mascot of this Team.


        :param mascot: The mascot of this Team.  # noqa: E501
        :type: str
        """

        self._mascot = mascot

    @property
    def abbreviation(self):
        """Gets the abbreviation of this Team.  # noqa: E501


        :return: The abbreviation of this Team.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this Team.


        :param abbreviation: The abbreviation of this Team.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def alt_name_1(self):
        """Gets the alt_name_1 of this Team.  # noqa: E501


        :return: The alt_name_1 of this Team.  # noqa: E501
        :rtype: str
        """
        return self._alt_name_1

    @alt_name_1.setter
    def alt_name_1(self, alt_name_1):
        """Sets the alt_name_1 of this Team.


        :param alt_name_1: The alt_name_1 of this Team.  # noqa: E501
        :type: str
        """

        self._alt_name_1 = alt_name_1

    @property
    def alt_name_2(self):
        """Gets the alt_name_2 of this Team.  # noqa: E501


        :return: The alt_name_2 of this Team.  # noqa: E501
        :rtype: str
        """
        return self._alt_name_2

    @alt_name_2.setter
    def alt_name_2(self, alt_name_2):
        """Sets the alt_name_2 of this Team.


        :param alt_name_2: The alt_name_2 of this Team.  # noqa: E501
        :type: str
        """

        self._alt_name_2 = alt_name_2

    @property
    def alt_name_3(self):
        """Gets the alt_name_3 of this Team.  # noqa: E501


        :return: The alt_name_3 of this Team.  # noqa: E501
        :rtype: str
        """
        return self._alt_name_3

    @alt_name_3.setter
    def alt_name_3(self, alt_name_3):
        """Sets the alt_name_3 of this Team.


        :param alt_name_3: The alt_name_3 of this Team.  # noqa: E501
        :type: str
        """

        self._alt_name_3 = alt_name_3

    @property
    def conference(self):
        """Gets the conference of this Team.  # noqa: E501


        :return: The conference of this Team.  # noqa: E501
        :rtype: str
        """
        return self._conference

    @conference.setter
    def conference(self, conference):
        """Sets the conference of this Team.


        :param conference: The conference of this Team.  # noqa: E501
        :type: str
        """

        self._conference = conference

    @property
    def division(self):
        """Gets the division of this Team.  # noqa: E501


        :return: The division of this Team.  # noqa: E501
        :rtype: str
        """
        return self._division

    @division.setter
    def division(self, division):
        """Sets the division of this Team.


        :param division: The division of this Team.  # noqa: E501
        :type: str
        """

        self._division = division

    @property
    def color(self):
        """Gets the color of this Team.  # noqa: E501


        :return: The color of this Team.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this Team.


        :param color: The color of this Team.  # noqa: E501
        :type: str
        """

        self._color = color

    @property
    def alt_color(self):
        """Gets the alt_color of this Team.  # noqa: E501


        :return: The alt_color of this Team.  # noqa: E501
        :rtype: str
        """
        return self._alt_color

    @alt_color.setter
    def alt_color(self, alt_color):
        """Sets the alt_color of this Team.


        :param alt_color: The alt_color of this Team.  # noqa: E501
        :type: str
        """

        self._alt_color = alt_color

    @property
    def logos(self):
        """Gets the logos of this Team.  # noqa: E501


        :return: The logos of this Team.  # noqa: E501
        :rtype: list[str]
        """
        return self._logos

    @logos.setter
    def logos(self, logos):
        """Sets the logos of this Team.


        :param logos: The logos of this Team.  # noqa: E501
        :type: list[str]
        """

        self._logos = logos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Team, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Team):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cfbd.api_client import ApiClient


class RatingsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_conference_sp_ratings(self, **kwargs):  # noqa: E501
        """Historical SP+ ratings by conference  # noqa: E501

        Get average SP+ historical rating data by conference  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_conference_sp_ratings(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Season filter
        :param str conference: Conference abbreviation filter
        :return: list[ConferenceSPRating]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_conference_sp_ratings_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_conference_sp_ratings_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_conference_sp_ratings_with_http_info(self, **kwargs):  # noqa: E501
        """Historical SP+ ratings by conference  # noqa: E501

        Get average SP+ historical rating data by conference  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_conference_sp_ratings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Season filter
        :param str conference: Conference abbreviation filter
        :return: list[ConferenceSPRating]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'conference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conference_sp_ratings" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 1970:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_conference_sp_ratings`, must be a value greater than or equal to `1970`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ratings/sp/conferences', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ConferenceSPRating]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_sp_ratings(self, **kwargs):  # noqa: E501
        """Historical SP+ ratings  # noqa: E501

        SP+ rating data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sp_ratings(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Season filter (required if team not specified)
        :param str team: Team filter (required if year not specified)
        :return: list[TeamSPRating]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_sp_ratings_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_sp_ratings_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_sp_ratings_with_http_info(self, **kwargs):  # noqa: E501
        """Historical SP+ ratings  # noqa: E501

        SP+ rating data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sp_ratings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Season filter (required if team not specified)
        :param str team: Team filter (required if year not specified)
        :return: list[TeamSPRating]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'team']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sp_ratings" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 1970:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_sp_ratings`, must be a value greater than or equal to `1970`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ratings/sp', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamSPRating]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_srs_ratings(self, **kwargs):  # noqa: E501
        """Historical SRS ratings  # noqa: E501

        SRS rating data (requires either a year or team specified)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_srs_ratings(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Season filter (required if team not specified)
        :param str team: Team filter (required if year not specified)
        :param str conference: Conference filter
        :return: list[TeamSRSRating]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_srs_ratings_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_srs_ratings_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_srs_ratings_with_http_info(self, **kwargs):  # noqa: E501
        """Historical SRS ratings  # noqa: E501

        SRS rating data (requires either a year or team specified)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_srs_ratings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Season filter (required if team not specified)
        :param str team: Team filter (required if year not specified)
        :param str conference: Conference filter
        :return: list[TeamSRSRating]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'team', 'conference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_srs_ratings" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 1897:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_srs_ratings`, must be a value greater than or equal to `1897`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ratings/srs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamSRSRating]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PositionGroupRecruitingRating(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'team': 'str',
        'conference': 'str',
        'positiion_group': 'str',
        'average_rating': 'float',
        'total_rating': 'float',
        'commits': 'float',
        'average_stars': 'float'
    }

    attribute_map = {
        'team': 'team',
        'conference': 'conference',
        'positiion_group': 'positiionGroup',
        'average_rating': 'averageRating',
        'total_rating': 'totalRating',
        'commits': 'commits',
        'average_stars': 'averageStars'
    }

    def __init__(self, team=None, conference=None, positiion_group=None, average_rating=None, total_rating=None, commits=None, average_stars=None):  # noqa: E501
        """PositionGroupRecruitingRating - a model defined in Swagger"""  # noqa: E501

        self._team = None
        self._conference = None
        self._positiion_group = None
        self._average_rating = None
        self._total_rating = None
        self._commits = None
        self._average_stars = None
        self.discriminator = None

        if team is not None:
            self.team = team
        if conference is not None:
            self.conference = conference
        if positiion_group is not None:
            self.positiion_group = positiion_group
        if average_rating is not None:
            self.average_rating = average_rating
        if total_rating is not None:
            self.total_rating = total_rating
        if commits is not None:
            self.commits = commits
        if average_stars is not None:
            self.average_stars = average_stars

    @property
    def team(self):
        """Gets the team of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The team of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this PositionGroupRecruitingRating.


        :param team: The team of this PositionGroupRecruitingRating.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def conference(self):
        """Gets the conference of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The conference of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: str
        """
        return self._conference

    @conference.setter
    def conference(self, conference):
        """Sets the conference of this PositionGroupRecruitingRating.


        :param conference: The conference of this PositionGroupRecruitingRating.  # noqa: E501
        :type: str
        """

        self._conference = conference

    @property
    def positiion_group(self):
        """Gets the positiion_group of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The positiion_group of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: str
        """
        return self._positiion_group

    @positiion_group.setter
    def positiion_group(self, positiion_group):
        """Sets the positiion_group of this PositionGroupRecruitingRating.


        :param positiion_group: The positiion_group of this PositionGroupRecruitingRating.  # noqa: E501
        :type: str
        """

        self._positiion_group = positiion_group

    @property
    def average_rating(self):
        """Gets the average_rating of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The average_rating of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: float
        """
        return self._average_rating

    @average_rating.setter
    def average_rating(self, average_rating):
        """Sets the average_rating of this PositionGroupRecruitingRating.


        :param average_rating: The average_rating of this PositionGroupRecruitingRating.  # noqa: E501
        :type: float
        """

        self._average_rating = average_rating

    @property
    def total_rating(self):
        """Gets the total_rating of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The total_rating of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: float
        """
        return self._total_rating

    @total_rating.setter
    def total_rating(self, total_rating):
        """Sets the total_rating of this PositionGroupRecruitingRating.


        :param total_rating: The total_rating of this PositionGroupRecruitingRating.  # noqa: E501
        :type: float
        """

        self._total_rating = total_rating

    @property
    def commits(self):
        """Gets the commits of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The commits of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: float
        """
        return self._commits

    @commits.setter
    def commits(self, commits):
        """Sets the commits of this PositionGroupRecruitingRating.


        :param commits: The commits of this PositionGroupRecruitingRating.  # noqa: E501
        :type: float
        """

        self._commits = commits

    @property
    def average_stars(self):
        """Gets the average_stars of this PositionGroupRecruitingRating.  # noqa: E501


        :return: The average_stars of this PositionGroupRecruitingRating.  # noqa: E501
        :rtype: float
        """
        return self._average_stars

    @average_stars.setter
    def average_stars(self, average_stars):
        """Sets the average_stars of this PositionGroupRecruitingRating.


        :param average_stars: The average_stars of this PositionGroupRecruitingRating.  # noqa: E501
        :type: float
        """

        self._average_stars = average_stars

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PositionGroupRecruitingRating, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PositionGroupRecruitingRating):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PlayerSearchResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'team': 'str',
        'name': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'weight': 'int',
        'height': 'int',
        'jersey': 'int',
        'position': 'str',
        'hometown': 'str',
        'team_color': 'str',
        'team_color_secondary': 'str'
    }

    attribute_map = {
        'id': 'id',
        'team': 'team',
        'name': 'name',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'weight': 'weight',
        'height': 'height',
        'jersey': 'jersey',
        'position': 'position',
        'hometown': 'hometown',
        'team_color': 'teamColor',
        'team_color_secondary': 'teamColorSecondary'
    }

    def __init__(self, id=None, team=None, name=None, first_name=None, last_name=None, weight=None, height=None, jersey=None, position=None, hometown=None, team_color=None, team_color_secondary=None):  # noqa: E501
        """PlayerSearchResult - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._team = None
        self._name = None
        self._first_name = None
        self._last_name = None
        self._weight = None
        self._height = None
        self._jersey = None
        self._position = None
        self._hometown = None
        self._team_color = None
        self._team_color_secondary = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if team is not None:
            self.team = team
        if name is not None:
            self.name = name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if weight is not None:
            self.weight = weight
        if height is not None:
            self.height = height
        if jersey is not None:
            self.jersey = jersey
        if position is not None:
            self.position = position
        if hometown is not None:
            self.hometown = hometown
        if team_color is not None:
            self.team_color = team_color
        if team_color_secondary is not None:
            self.team_color_secondary = team_color_secondary

    @property
    def id(self):
        """Gets the id of this PlayerSearchResult.  # noqa: E501


        :return: The id of this PlayerSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PlayerSearchResult.


        :param id: The id of this PlayerSearchResult.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def team(self):
        """Gets the team of this PlayerSearchResult.  # noqa: E501


        :return: The team of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this PlayerSearchResult.


        :param team: The team of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def name(self):
        """Gets the name of this PlayerSearchResult.  # noqa: E501


        :return: The name of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PlayerSearchResult.


        :param name: The name of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def first_name(self):
        """Gets the first_name of this PlayerSearchResult.  # noqa: E501


        :return: The first_name of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this PlayerSearchResult.


        :param first_name: The first_name of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this PlayerSearchResult.  # noqa: E501


        :return: The last_name of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this PlayerSearchResult.


        :param last_name: The last_name of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def weight(self):
        """Gets the weight of this PlayerSearchResult.  # noqa: E501


        :return: The weight of this PlayerSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this PlayerSearchResult.


        :param weight: The weight of this PlayerSearchResult.  # noqa: E501
        :type: int
        """

        self._weight = weight

    @property
    def height(self):
        """Gets the height of this PlayerSearchResult.  # noqa: E501


        :return: The height of this PlayerSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this PlayerSearchResult.


        :param height: The height of this PlayerSearchResult.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def jersey(self):
        """Gets the jersey of this PlayerSearchResult.  # noqa: E501


        :return: The jersey of this PlayerSearchResult.  # noqa: E501
        :rtype: int
        """
        return self._jersey

    @jersey.setter
    def jersey(self, jersey):
        """Sets the jersey of this PlayerSearchResult.


        :param jersey: The jersey of this PlayerSearchResult.  # noqa: E501
        :type: int
        """

        self._jersey = jersey

    @property
    def position(self):
        """Gets the position of this PlayerSearchResult.  # noqa: E501


        :return: The position of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this PlayerSearchResult.


        :param position: The position of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._position = position

    @property
    def hometown(self):
        """Gets the hometown of this PlayerSearchResult.  # noqa: E501


        :return: The hometown of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._hometown

    @hometown.setter
    def hometown(self, hometown):
        """Sets the hometown of this PlayerSearchResult.


        :param hometown: The hometown of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._hometown = hometown

    @property
    def team_color(self):
        """Gets the team_color of this PlayerSearchResult.  # noqa: E501


        :return: The team_color of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._team_color

    @team_color.setter
    def team_color(self, team_color):
        """Sets the team_color of this PlayerSearchResult.


        :param team_color: The team_color of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._team_color = team_color

    @property
    def team_color_secondary(self):
        """Gets the team_color_secondary of this PlayerSearchResult.  # noqa: E501


        :return: The team_color_secondary of this PlayerSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._team_color_secondary

    @team_color_secondary.setter
    def team_color_secondary(self, team_color_secondary):
        """Sets the team_color_secondary of this PlayerSearchResult.


        :param team_color_secondary: The team_color_secondary of this PlayerSearchResult.  # noqa: E501
        :type: str
        """

        self._team_color_secondary = team_color_secondary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayerSearchResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayerSearchResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TeamRecordTotal(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'games': 'int',
        'wins': 'int',
        'losses': 'int',
        'ties': 'int'
    }

    attribute_map = {
        'games': 'games',
        'wins': 'wins',
        'losses': 'losses',
        'ties': 'ties'
    }

    def __init__(self, games=None, wins=None, losses=None, ties=None):  # noqa: E501
        """TeamRecordTotal - a model defined in Swagger"""  # noqa: E501

        self._games = None
        self._wins = None
        self._losses = None
        self._ties = None
        self.discriminator = None

        if games is not None:
            self.games = games
        if wins is not None:
            self.wins = wins
        if losses is not None:
            self.losses = losses
        if ties is not None:
            self.ties = ties

    @property
    def games(self):
        """Gets the games of this TeamRecordTotal.  # noqa: E501


        :return: The games of this TeamRecordTotal.  # noqa: E501
        :rtype: int
        """
        return self._games

    @games.setter
    def games(self, games):
        """Sets the games of this TeamRecordTotal.


        :param games: The games of this TeamRecordTotal.  # noqa: E501
        :type: int
        """

        self._games = games

    @property
    def wins(self):
        """Gets the wins of this TeamRecordTotal.  # noqa: E501


        :return: The wins of this TeamRecordTotal.  # noqa: E501
        :rtype: int
        """
        return self._wins

    @wins.setter
    def wins(self, wins):
        """Sets the wins of this TeamRecordTotal.


        :param wins: The wins of this TeamRecordTotal.  # noqa: E501
        :type: int
        """

        self._wins = wins

    @property
    def losses(self):
        """Gets the losses of this TeamRecordTotal.  # noqa: E501


        :return: The losses of this TeamRecordTotal.  # noqa: E501
        :rtype: int
        """
        return self._losses

    @losses.setter
    def losses(self, losses):
        """Sets the losses of this TeamRecordTotal.


        :param losses: The losses of this TeamRecordTotal.  # noqa: E501
        :type: int
        """

        self._losses = losses

    @property
    def ties(self):
        """Gets the ties of this TeamRecordTotal.  # noqa: E501


        :return: The ties of this TeamRecordTotal.  # noqa: E501
        :rtype: int
        """
        return self._ties

    @ties.setter
    def ties(self, ties):
        """Sets the ties of this TeamRecordTotal.


        :param ties: The ties of this TeamRecordTotal.  # noqa: E501
        :type: int
        """

        self._ties = ties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamRecordTotal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamRecordTotal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PlayType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'text': 'str',
        'abbreviation': 'str'
    }

    attribute_map = {
        'id': 'id',
        'text': 'text',
        'abbreviation': 'abbreviation'
    }

    def __init__(self, id=None, text=None, abbreviation=None):  # noqa: E501
        """PlayType - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._text = None
        self._abbreviation = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if text is not None:
            self.text = text
        if abbreviation is not None:
            self.abbreviation = abbreviation

    @property
    def id(self):
        """Gets the id of this PlayType.  # noqa: E501


        :return: The id of this PlayType.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PlayType.


        :param id: The id of this PlayType.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def text(self):
        """Gets the text of this PlayType.  # noqa: E501


        :return: The text of this PlayType.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this PlayType.


        :param text: The text of this PlayType.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def abbreviation(self):
        """Gets the abbreviation of this PlayType.  # noqa: E501


        :return: The abbreviation of this PlayType.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this PlayType.


        :param abbreviation: The abbreviation of this PlayType.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.api.metrics_api import MetricsApi  # noqa: E501
from cfbd.rest import ApiException


class TestMetricsApi(unittest.TestCase):
    """MetricsApi unit test stubs"""

    def setUp(self):
        self.api = cfbd.api.metrics_api.MetricsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_game_ppa(self):
        """Test case for get_game_ppa

        Team Predicated Points Added (PPA/EPA) by game  # noqa: E501
        """
        pass

    def test_get_player_game_ppa(self):
        """Test case for get_player_game_ppa

        Player Predicated Points Added (PPA/EPA) broken down by game  # noqa: E501
        """
        pass

    def test_get_player_season_ppa(self):
        """Test case for get_player_season_ppa

        Player Predicated Points Added (PPA/EPA) broken down by season  # noqa: E501
        """
        pass

    def test_get_predicted_points(self):
        """Test case for get_predicted_points

        Predicted Points (i.e. Expected Points or EP)  # noqa: E501
        """
        pass

    def test_get_pregame_win_probabilities(self):
        """Test case for get_pregame_win_probabilities

        Pregame win probability data  # noqa: E501
        """
        pass

    def test_get_team_ppa(self):
        """Test case for get_team_ppa

        Predicted Points Added (PPA/EPA) data by team  # noqa: E501
        """
        pass

    def test_get_win_probability_data(self):
        """Test case for get_win_probability_data

        Win probability chart data  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cfbd.api.betting_api import BettingApi
from cfbd.api.coaches_api import CoachesApi
from cfbd.api.conferences_api import ConferencesApi
from cfbd.api.drives_api import DrivesApi
from cfbd.api.games_api import GamesApi
from cfbd.api.metrics_api import MetricsApi
from cfbd.api.players_api import PlayersApi
from cfbd.api.plays_api import PlaysApi
from cfbd.api.rankings_api import RankingsApi
from cfbd.api.ratings_api import RatingsApi
from cfbd.api.recruiting_api import RecruitingApi
from cfbd.api.stats_api import StatsApi
from cfbd.api.teams_api import TeamsApi
from cfbd.api.venues_api import VenuesApi



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PlayerSeasonPPAAveragePPA(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'all': 'float',
        '_pass': 'float',
        'rush': 'float',
        'first_down': 'float',
        'second_down': 'float',
        'third_down': 'float',
        'standard_downs': 'float',
        'passing_downs': 'float'
    }

    attribute_map = {
        'all': 'all',
        '_pass': 'pass',
        'rush': 'rush',
        'first_down': 'firstDown',
        'second_down': 'secondDown',
        'third_down': 'thirdDown',
        'standard_downs': 'standardDowns',
        'passing_downs': 'passingDowns'
    }

    def __init__(self, all=None, _pass=None, rush=None, first_down=None, second_down=None, third_down=None, standard_downs=None, passing_downs=None):  # noqa: E501
        """PlayerSeasonPPAAveragePPA - a model defined in Swagger"""  # noqa: E501

        self._all = None
        self.__pass = None
        self._rush = None
        self._first_down = None
        self._second_down = None
        self._third_down = None
        self._standard_downs = None
        self._passing_downs = None
        self.discriminator = None

        if all is not None:
            self.all = all
        if _pass is not None:
            self._pass = _pass
        if rush is not None:
            self.rush = rush
        if first_down is not None:
            self.first_down = first_down
        if second_down is not None:
            self.second_down = second_down
        if third_down is not None:
            self.third_down = third_down
        if standard_downs is not None:
            self.standard_downs = standard_downs
        if passing_downs is not None:
            self.passing_downs = passing_downs

    @property
    def all(self):
        """Gets the all of this PlayerSeasonPPAAveragePPA.  # noqa: E501


        :return: The all of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :rtype: float
        """
        return self._all

    @all.setter
    def all(self, all):
        """Sets the all of this PlayerSeasonPPAAveragePPA.


        :param all: The all of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :type: float
        """

        self._all = all

    @property
    def _pass(self):
        """Gets the _pass of this PlayerSeasonPPAAveragePPA.  # noqa: E501


        :return: The _pass of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :rtype: float
        """
        return self.__pass

    @_pass.setter
    def _pass(self, _pass):
        """Sets the _pass of this PlayerSeasonPPAAveragePPA.


        :param _pass: The _pass of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :type: float
        """

        self.__pass = _pass

    @property
    def rush(self):
        """Gets the rush of this PlayerSeasonPPAAveragePPA.  # noqa: E501


        :return: The rush of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :rtype: float
        """
        return self._rush

    @rush.setter
    def rush(self, rush):
        """Sets the rush of this PlayerSeasonPPAAveragePPA.


        :param rush: The rush of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :type: float
        """

        self._rush = rush

    @property
    def first_down(self):
        """Gets the first_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501


        :return: The first_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :rtype: float
        """
        return self._first_down

    @first_down.setter
    def first_down(self, first_down):
        """Sets the first_down of this PlayerSeasonPPAAveragePPA.


        :param first_down: The first_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :type: float
        """

        self._first_down = first_down

    @property
    def second_down(self):
        """Gets the second_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501


        :return: The second_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :rtype: float
        """
        return self._second_down

    @second_down.setter
    def second_down(self, second_down):
        """Sets the second_down of this PlayerSeasonPPAAveragePPA.


        :param second_down: The second_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :type: float
        """

        self._second_down = second_down

    @property
    def third_down(self):
        """Gets the third_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501


        :return: The third_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :rtype: float
        """
        return self._third_down

    @third_down.setter
    def third_down(self, third_down):
        """Sets the third_down of this PlayerSeasonPPAAveragePPA.


        :param third_down: The third_down of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :type: float
        """

        self._third_down = third_down

    @property
    def standard_downs(self):
        """Gets the standard_downs of this PlayerSeasonPPAAveragePPA.  # noqa: E501


        :return: The standard_downs of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :rtype: float
        """
        return self._standard_downs

    @standard_downs.setter
    def standard_downs(self, standard_downs):
        """Sets the standard_downs of this PlayerSeasonPPAAveragePPA.


        :param standard_downs: The standard_downs of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :type: float
        """

        self._standard_downs = standard_downs

    @property
    def passing_downs(self):
        """Gets the passing_downs of this PlayerSeasonPPAAveragePPA.  # noqa: E501


        :return: The passing_downs of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :rtype: float
        """
        return self._passing_downs

    @passing_downs.setter
    def passing_downs(self, passing_downs):
        """Sets the passing_downs of this PlayerSeasonPPAAveragePPA.


        :param passing_downs: The passing_downs of this PlayerSeasonPPAAveragePPA.  # noqa: E501
        :type: float
        """

        self._passing_downs = passing_downs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayerSeasonPPAAveragePPA, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayerSeasonPPAAveragePPA):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Venue(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'capacity': 'int',
        'grass': 'bool',
        'city': 'str',
        'state': 'str',
        'zip': 'str',
        'country_code': 'str',
        'location': 'VenueLocation',
        'elevation': 'int',
        'year': 'int',
        'dome': 'bool',
        'timezone': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'capacity': 'capacity',
        'grass': 'grass',
        'city': 'city',
        'state': 'state',
        'zip': 'zip',
        'country_code': 'country_code',
        'location': 'location',
        'elevation': 'elevation',
        'year': 'year',
        'dome': 'dome',
        'timezone': 'timezone'
    }

    def __init__(self, id=None, name=None, capacity=None, grass=None, city=None, state=None, zip=None, country_code=None, location=None, elevation=None, year=None, dome=None, timezone=None):  # noqa: E501
        """Venue - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._capacity = None
        self._grass = None
        self._city = None
        self._state = None
        self._zip = None
        self._country_code = None
        self._location = None
        self._elevation = None
        self._year = None
        self._dome = None
        self._timezone = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if capacity is not None:
            self.capacity = capacity
        if grass is not None:
            self.grass = grass
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if zip is not None:
            self.zip = zip
        if country_code is not None:
            self.country_code = country_code
        if location is not None:
            self.location = location
        if elevation is not None:
            self.elevation = elevation
        if year is not None:
            self.year = year
        if dome is not None:
            self.dome = dome
        if timezone is not None:
            self.timezone = timezone

    @property
    def id(self):
        """Gets the id of this Venue.  # noqa: E501


        :return: The id of this Venue.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Venue.


        :param id: The id of this Venue.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Venue.  # noqa: E501


        :return: The name of this Venue.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Venue.


        :param name: The name of this Venue.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def capacity(self):
        """Gets the capacity of this Venue.  # noqa: E501


        :return: The capacity of this Venue.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this Venue.


        :param capacity: The capacity of this Venue.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def grass(self):
        """Gets the grass of this Venue.  # noqa: E501


        :return: The grass of this Venue.  # noqa: E501
        :rtype: bool
        """
        return self._grass

    @grass.setter
    def grass(self, grass):
        """Sets the grass of this Venue.


        :param grass: The grass of this Venue.  # noqa: E501
        :type: bool
        """

        self._grass = grass

    @property
    def city(self):
        """Gets the city of this Venue.  # noqa: E501


        :return: The city of this Venue.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Venue.


        :param city: The city of this Venue.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this Venue.  # noqa: E501


        :return: The state of this Venue.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Venue.


        :param state: The state of this Venue.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def zip(self):
        """Gets the zip of this Venue.  # noqa: E501


        :return: The zip of this Venue.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this Venue.


        :param zip: The zip of this Venue.  # noqa: E501
        :type: str
        """

        self._zip = zip

    @property
    def country_code(self):
        """Gets the country_code of this Venue.  # noqa: E501


        :return: The country_code of this Venue.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this Venue.


        :param country_code: The country_code of this Venue.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def location(self):
        """Gets the location of this Venue.  # noqa: E501


        :return: The location of this Venue.  # noqa: E501
        :rtype: VenueLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this Venue.


        :param location: The location of this Venue.  # noqa: E501
        :type: VenueLocation
        """

        self._location = location

    @property
    def elevation(self):
        """Gets the elevation of this Venue.  # noqa: E501


        :return: The elevation of this Venue.  # noqa: E501
        :rtype: int
        """
        return self._elevation

    @elevation.setter
    def elevation(self, elevation):
        """Sets the elevation of this Venue.


        :param elevation: The elevation of this Venue.  # noqa: E501
        :type: int
        """

        self._elevation = elevation

    @property
    def year(self):
        """Gets the year of this Venue.  # noqa: E501


        :return: The year of this Venue.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this Venue.


        :param year: The year of this Venue.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def dome(self):
        """Gets the dome of this Venue.  # noqa: E501


        :return: The dome of this Venue.  # noqa: E501
        :rtype: bool
        """
        return self._dome

    @dome.setter
    def dome(self, dome):
        """Sets the dome of this Venue.


        :param dome: The dome of this Venue.  # noqa: E501
        :type: bool
        """

        self._dome = dome

    @property
    def timezone(self):
        """Gets the timezone of this Venue.  # noqa: E501


        :return: The timezone of this Venue.  # noqa: E501
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this Venue.


        :param timezone: The timezone of this Venue.  # noqa: E501
        :type: str
        """

        self._timezone = timezone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Venue, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Venue):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
